import 'package:http/http.dart' as http;
import 'dart:io';
import 'dart:async';

class ConnectionUtils {
  static Future<bool> isResponseSuccessful(String url,
      {Duration? timeout, int? timeoutMillis}) async {
    final future = http.head(Uri.parse(url));
    if (timeoutMillis != null) timeout = Duration(milliseconds: timeoutMillis);
    final response = await (timeout == null
        ? future
        : future.timeout(timeout,
            onTimeout: () => http.Response('', HttpStatus.requestTimeout)));
    return response.statusCode >= 200 || response.statusCode < 300;
  }

  static Future<bool> isResponseOnline(String url,
      {Duration? timeout, int? timeoutMillis}) async {
    final future = http.head(Uri.parse(url));
    if (timeoutMillis != null) timeout = Duration(milliseconds: timeoutMillis);
    final response = await (timeout == null
        ? future
        : future.timeout(timeout,
            onTimeout: () => http.Response('', HttpStatus.requestTimeout)));
    switch (response.statusCode) {
      case HttpStatus.notFound:
      case HttpStatus.requestTimeout:
      case HttpStatus.gatewayTimeout:
      case HttpStatus.networkConnectTimeoutError:
        return false;
    }
    return true;
  }
}
