import 'package:url_launcher/url_launcher.dart';

class IntentUtils {
  static Future<bool> launchURL(String url) async {
    try {
      String suitableURL;
      if (!url.startsWith("http://") &&
          !url.startsWith("https://") &&
          !url.startsWith("ftp://") &&
          !url.startsWith("file://")) {
        suitableURL = "http://$url";
      } else {
        suitableURL = url;
      }

      final bool nativeAppLaunchSucceeded = await launch(
        suitableURL,
        forceSafariVC: false,
        universalLinksOnly: true,
      );

      if (nativeAppLaunchSucceeded) return true;

      return await launch(
        suitableURL,
        forceSafariVC: true,
      );
    } catch (e) {
      print(e);
    }
    return false;
  }

  static Future<bool> launchWhatsApp(String phoneNumber) async =>
      await launchURL('https://wa.me/$phoneNumber');

  static Future<bool> launchMessenger(String username) async =>
      await launchURL('https://m.me/$username');

  static Future<bool> launchTelegram(String username) async =>
      await launchURL('https://telegram.me/$username');

  static Future<bool> sendEmail(String address,
      {String subject = '', String body = ''}) async {
    try {
      return launch("mailto:$address?subject=$subject&body=$body");
    } catch (e) {
      print(e);
    }
    return false;
  }

  static Future<bool> sendSMS(String phoneNumber) async {
    try {
      return launch("sms:${phoneNumber.split(" ").join()}");
    } catch (e) {
      print(e);
    }
    return false;
  }

  static Future<bool> call(String phoneNumber) async {
    try {
      return launch("tel:${phoneNumber.split(" ").join()}");
    } catch (e) {
      print(e);
    }
    return false;
  }
}
